@@ -1681,6 +1681,47 @@ def matrix01(df, other_matrix_type, upperleft_diag_matrix_type):
     plt.show()
 
 
+# matrix plot: add category distribution. 1.scatter+hist; 2.scatter+kde; 3.kde+kde
+def matrix02(df, category, other_matrix_type, upperleft_diag_matrix_type):
+    import seaborn as sns
+    import numpy as np
+    import matplotlib.pyplot as plt
+
+    df = df
+
+    #     plt.figure(figsize=(12,8))
+
+    kind = other_matrix_type;
+    diag_kind = upperleft_diag_matrix_type;
+
+    if kind == 'scatter' and diag_kind == 'hist':
+
+        g = sns.pairplot(
+            df, kind=kind, diag_kind=diag_kind, hue=category,
+            plot_kws=dict(s=90, edgecolor="white", alpha=.5, linewidth=1),
+            diag_kws=dict(edgecolor="white", alpha=.8, linewidth=1.5))
+
+    elif kind == 'scatter' and diag_kind == 'kde':
+        g = sns.pairplot(
+            df, kind=kind, diag_kind=diag_kind, hue=category,
+            plot_kws=dict(s=80, edgecolor="white", alpha=.5, linewidth=1))
+    #             diag_kws=dict(edgecolor="white",alpha=.8,linewidth=1.5))
+
+    elif kind == 'kde' and diag_kind == 'kde':
+
+        g = sns.pairplot(df, diag_kind="kde", hue=category,
+                         plot_kws=dict(s=80, edgecolor="white", alpha=.5, linewidth=1),
+                         )  # kde-核密度估计图
+        g.map_lower(sns.kdeplot, levels=5, color="grey")
+
+    else:
+        nothing = 'do nothing'
+
+    for ax in g.axes.flat:
+        ax.grid(True, axis='both', alpha=0.3)
+
+    plt.show()
+
 
 
 # show correlation line + error zone. with scatter plot:
